/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid;

import java.util.Optional;
import java.util.stream.Stream;

import de.ozgcloud.document.bescheid.BescheidServiceGrpc.BescheidServiceImplBase;
import de.ozgcloud.document.bescheid.vorgang.VorgangId;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
@RequiredArgsConstructor
class BescheidGrpcService extends BescheidServiceImplBase {

	private final BescheidService service;
	private final BescheidMapper mapper;

	@Override
	public void getBescheidDraft(GrpcGetBescheidDraftRequest request, StreamObserver<GrpcGetBescheidDraftResponse> responseObserver) {
		var bescheidDraft = service.findDraft(request.getVorgangId());

		responseObserver.onNext(buildGetBescheidDraftResponse(bescheidDraft));
		responseObserver.onCompleted();
	}

	private GrpcGetBescheidDraftResponse buildGetBescheidDraftResponse(Optional<Bescheid> bescheidDraft) {
		return bescheidDraft.map(mapper::toGetBescheidDraftResponse).orElseGet(GrpcGetBescheidDraftResponse::getDefaultInstance);
	}

	@Override
	public void getConfig(GrpcBescheidManagerConfigRequest request, StreamObserver<GrpcBescheidManagerConfigResponse> responseObserver) {
		responseObserver.onNext(mapper.fromBescheidManagerConfig(service.getConfig()));
		responseObserver.onCompleted();
	}

	@Override
	public void getAll(GrpcGetAllBescheidRequest request, StreamObserver<GrpcGetAllBescheidResponse> responseObserver) {
		var bescheide = service.findAll(VorgangId.from(request.getVorgangId()));

		responseObserver.onNext(buildGetAllBescheidResponse(bescheide));
		responseObserver.onCompleted();
	}

	GrpcGetAllBescheidResponse buildGetAllBescheidResponse(Stream<Bescheid> bescheidItems) {
		return GrpcGetAllBescheidResponse.newBuilder().addAllBescheid(bescheidItems.map(mapper::toBescheid).toList()).build();
	}

	@Override
	public void getBescheid(GrpcGetBescheidRequest request, StreamObserver<GrpcGetBescheidResponse> responseObserver) {
		var bescheid = service.getBescheid(request.getId());

		responseObserver.onNext(mapper.toGetBescheidResponse(bescheid));
		responseObserver.onCompleted();
	}
}