/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid;

import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN, collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED)
public interface SentInfoMapper {

	String GRPC_DATE_TIME_FORMATTER = "yyyy-MM-dd'T'HH:mm:ss'Z'";

	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "sentAtBytes", ignore = true)
	@Mapping(target = "sentByBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "sentAt", source = "sentAt", dateFormat = GRPC_DATE_TIME_FORMATTER)
	GrpcSentInfo mapTo(SentInfo sentInfo);

	default SentInfo toSentInfo(Map<String, Object> sentInfoMap) {
		return SentInfo.builder()
				.sentBy(MapUtils.getString(sentInfoMap, SentInfo.FIELD_SENT_BY))
				.sentAt(ZonedDateTime.parse(MapUtils.getString(sentInfoMap, SentInfo.FIELD_SENT_AT), DateTimeFormatter.ISO_DATE_TIME))
				.build();
	}

	default Map<String, Object> toMap(SentInfo sentInfo) {
		var result = new HashMap<String, Object>();
		result.put(SentInfo.FIELD_SENT_BY, sentInfo.getSentBy());
		result.put(SentInfo.FIELD_SENT_AT, sentInfo.getSentAt().format(DateTimeFormatter.ISO_DATE_TIME));
		return Collections.unmodifiableMap(result);
	}
}
