/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid.dummy;

import java.util.Optional;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Service;

import com.google.common.net.MediaType;

import de.ozgcloud.document.bescheid.BescheidResponse;
import de.ozgcloud.document.bescheid.BescheidRemoteService;
import de.ozgcloud.document.bescheid.BescheidRequest;
import de.ozgcloud.document.bescheid.vorgang.Vorgang;
import de.ozgcloud.common.binaryfile.TempFileUtils;

@Service
@ConditionalOnProperty("ozgcloud.feature.bescheid.enable-dummy-document-processor")
class DummyBescheidRemoteService implements BescheidRemoteService {

	private static final String DUMMY_BESCHEID_FILE_NAME = "dummy-bescheid.pdf";
	private static final String DUMMY_BESCHEID_CONTENT_TYPE = MediaType.PDF.toString();

	@Override
	public BescheidResponse create(BescheidRequest request, Vorgang vorgang) {
		var file = TempFileUtils.writeTmpFile(this.getClass().getClassLoader().getResourceAsStream(DUMMY_BESCHEID_FILE_NAME));

		return BescheidResponse.builder()
				.bescheidFile(file)
				.bescheidFileName(DUMMY_BESCHEID_FILE_NAME)
				.contentType(DUMMY_BESCHEID_CONTENT_TYPE)
				.nachrichtText(Optional.of("Dummy Bescheid"))
				.nachrichtSubject(Optional.of("Nachricht Subject"))
				.size(file.length())
				.createdBy(request.getCreateFor().getId())
				.build();
	}

}
