/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid.vorgang;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import lombok.Builder;
import lombok.Getter;
import lombok.Singular;

@JsonSerialize(using = FormDataEntrySerializer.class)
public interface FormDataEntry {

	String getName();

	@JsonIgnore
	String getLabel();

	@JsonIgnore
	default boolean isSubForm() {
		return false;
	}

	@JsonIgnore
	default boolean isFormEntry() {
		return false;
	}

	@Builder
	@Getter
	static class SubForm implements FormDataEntry {

		private String name;
		@JsonIgnore
		private String label;

		@Singular
		private List<FormDataEntry> entries;

		@JsonIgnore
		@Override
		public boolean isSubForm() {
			return true;
		}
	}

	@Builder
	@Getter
	static class FormField implements FormDataEntry {

		private String name;
		@JsonIgnore
		private String label;

		private Object value;

		@JsonIgnore
		@Override
		public boolean isFormEntry() {
			return true;
		}
	}
}
