/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import io.grpc.stub.StreamObserver;

class DocumentGrpcServiceTest {

	@Spy
	@InjectMocks
	private DocumentGrpcService service;

	@Mock
	private DocumentService documentService;
	@Mock
	private DocumentMapper documentMapper;

	@Nested
	class TestGetDocument {

		private final static GrpcGetDocumentRequest REQUEST = GrpcGetDocumentRequest.newBuilder().setId(DocumentTestFactory.ID).build();

		@Mock
		private GrpcGetDocumentResponse response;
		@Mock
		private StreamObserver<GrpcGetDocumentResponse> responseObserver;

		@BeforeEach
		void init() {
			doReturn(response).when(service).buildGetDocumentResponse(any());
		}

		@Test
		void shouldCallDocumentService() {
			service.getDocument(REQUEST, responseObserver);

			verify(documentService).getDocument(DocumentTestFactory.ID);
		}

		@Test
		void shouldCallBuildResponse() {
			service.getDocument(REQUEST, responseObserver);

			verify(service).buildGetDocumentResponse(any());
		}

		@Test
		void shouldCallOnNext() {
			service.getDocument(REQUEST, responseObserver);

			verify(responseObserver).onNext(response);
		}

		@Test
		void shouldCallOnCompleted() {
			service.getDocument(REQUEST, responseObserver);

			verify(responseObserver).onCompleted();
		}
	}

	@Nested
	class TestBuildGetDocumentResponse {

		@Mock
		private GrpcDocument grpcDocument;

		@BeforeEach
		void init() {
			when(documentMapper.toGrpcDocument(any())).thenReturn(grpcDocument);
		}

		@Test
		void shouldCallDocumentMapper() {
			var document = DocumentTestFactory.create();

			service.buildGetDocumentResponse(document);

			verify(documentMapper).toGrpcDocument(document);
		}

		@Test
		void shouldSetDocument() {
			var result = service.buildGetDocumentResponse(DocumentTestFactory.create());

			assertThat(result.getDocument()).isEqualTo(grpcDocument);
		}
	}
}