/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid;

import java.io.File;
import java.util.Optional;

import org.springframework.http.MediaType;

import de.ozgcloud.document.bescheid.common.user.UserProfileTestFactory;
import de.ozgcloud.document.bescheid.vorgang.ServiceKontoTestFactory;
import de.ozgcloud.document.bescheid.vorgang.VorgangTestFactory;
import de.ozgcloud.common.binaryfile.FileId;
import de.ozgcloud.common.binaryfile.TempFileUtils;
import de.ozgcloud.document.DocumentTestFactory;

public class BescheidResponseTestFactory {

	public static final String BESCHEID_FILE_NAME = "testbescheid";
	public static final File BESCHEID_FILE = TempFileUtils.writeTmpFile(BESCHEID_FILE_NAME.getBytes());
	public static final int BESCHEID_FILE_SIZE = BESCHEID_FILE_NAME.getBytes().length;

	public static final String CONTENT_TYPE = MediaType.APPLICATION_PDF_VALUE;

	public static BescheidResponse create() {
		return createBuilder().build();
	}

	public static BescheidResponse.BescheidResponseBuilder createBuilder() {
		return BescheidResponse.builder()
				.createdBy(UserProfileTestFactory.ID)
				.vorgangId(VorgangTestFactory.ID)
				.contentType(CONTENT_TYPE)
				.bescheidFileName(BESCHEID_FILE_NAME)
				.bescheidFile(BESCHEID_FILE)
				.bescheidFileId(FileId.from(DocumentTestFactory.ID))
				.nachrichtSubject(Optional.of(BescheidTestFactory.NACHRICHT_SUBJECT))
				.nachrichtText(Optional.of(BescheidTestFactory.NACHRICHT_TEXT))
				.bewilligt(BescheidTestFactory.BEWILLIGT)
				.size(BESCHEID_FILE_SIZE)
				.attachments(BescheidTestFactory.ATTACHMENTS)
				.serviceKonto(ServiceKontoTestFactory.create());
	}
}
