/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid;

import java.time.LocalDate;
import java.util.List;
import java.util.Optional;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.document.bescheid.Bescheid.SendBy;
import de.ozgcloud.document.bescheid.Bescheid.Status;
import de.ozgcloud.document.bescheid.common.user.UserProfileTestFactory;
import de.ozgcloud.document.bescheid.vorgang.VorgangTestFactory;
import de.ozgcloud.document.common.attached_item.AttachedItemTestFactory;
import de.ozgcloud.common.binaryfile.FileId;
import de.ozgcloud.document.DocumentTestFactory;

public class BescheidTestFactory {

	public final static boolean BEWILLIGT = true;

	public final static BescheidId ID = BescheidId.from(AttachedItemTestFactory.ID);
	public final static Status STATUS = Status.DRAFT;
	public final static String BESCHIEDEN_AM_STR = "2021-01-10";
	public final static LocalDate BESCHIEDEN_AM = LocalDate.parse(BESCHIEDEN_AM_STR);
	public final static SendBy SEND_BY = SendBy.NACHRICHT;

	public final static String NACHRICHT_TEXT = LoremIpsum.getInstance().getWords(5);
	public final static String NACHRICHT_SUBJECT = LoremIpsum.getInstance().getWords(5);

	public final static String ATTACHMENT_STR = UUID.randomUUID().toString();
	public final static FileId ATTACHMENT = FileId.from(ATTACHMENT_STR);
	public final static List<FileId> ATTACHMENTS = List.of(ATTACHMENT, ATTACHMENT);

	public final static SentInfo SENT_INFO = SentInfoTestFactory.create();

	public static Bescheid create() {
		return createBuilder().build();
	}

	public static Bescheid.BescheidBuilder createBuilder() {
		return Bescheid.builder()
				.id(ID)
				.version(AttachedItemTestFactory.VERSION)
				.vorgangId(VorgangTestFactory.ID)
				.createdBy(UserProfileTestFactory.ID)
				.bewilligt(BEWILLIGT)
				.status(STATUS)
				.bescheidDocument(FileId.from(DocumentTestFactory.ID))
				.beschiedenAm(BESCHIEDEN_AM)
				.sendBy(SEND_BY)
				.sentInfo(SENT_INFO)
				.nachrichtSubject(Optional.of(NACHRICHT_SUBJECT))
				.nachrichtText(Optional.of(NACHRICHT_TEXT))
				.attachments(ATTACHMENTS);
	}
}