/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;

class BescheidVorgangMapperTest {

	@InjectMocks
	private final BescheidVorgangMapper mapper = Mappers.getMapper(BescheidVorgangMapper.class);

	@Nested
	class TestMapVorgang {

		@Test
		void shouldMapEingang() {
			var result = mapper.mapVorgang(GrpcVorgangWithEingangTestFactory.create());

			assertThat(result.getEingang()).isNotNull();
		}

		@Test
		void shouldMapVorgangId() {
			var result = mapper.mapVorgang(GrpcVorgangWithEingangTestFactory.create());

			assertThat(result.getId()).isEqualTo(VorgangTestFactory.ID);
		}

		@Test
		void shouldMapVersion() {
			var result = mapper.mapVorgang(GrpcVorgangWithEingangTestFactory.create());

			assertThat(result.getVersion()).isEqualTo(VorgangTestFactory.VERSION);
		}
	}
}
