/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.document.bescheid.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangWithEingangRequest;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc.VorgangServiceBlockingStub;

class VorgangRemoteServiceTest {

	@Spy
	@InjectMocks
	private VorgangRemoteService service;

	@Mock
	private VorgangServiceBlockingStub serviceStub;
	@Mock
	private BescheidVorgangMapper mapper;

	@Nested
	class TestGetById {
		@Captor
		private ArgumentCaptor<GrpcFindVorgangWithEingangRequest> requestCaptor;

		@BeforeEach
		void prepareGrpc() {
			when(serviceStub.withInterceptors(any())).thenReturn(serviceStub);
			when(serviceStub.findVorgangWithEingang(any())).thenReturn(GrpcVorgangWithEingangTestFactory.createResponse());

		}

		@BeforeEach
		void init() {
			when(mapper.mapVorgang(any())).thenReturn(VorgangTestFactory.create());
		}

		@Test
		void shouldCallStubWithId() {
			service.getById(VorgangTestFactory.ID);

			verify(serviceStub).findVorgangWithEingang(requestCaptor.capture());
			assertThat(requestCaptor.getValue()).extracting(GrpcFindVorgangWithEingangRequest::getId).isEqualTo(VorgangTestFactory.ID.toString());
		}

		@Test
		void shouldCallMapper() {
			service.getById(VorgangTestFactory.ID);

			verify(mapper).mapVorgang(any());
		}

		@Test
		void shouldReturnVorgang() {
			var vorgang = service.getById(VorgangTestFactory.ID);

			assertThat(vorgang).usingRecursiveComparison().isEqualTo(VorgangTestFactory.create());
		}

	}

}
